Title: [235754] trunk
Revision
235754
Author
[email protected]
Date
2018-09-06 13:42:48 -0700 (Thu, 06 Sep 2018)

Log Message

[Apple Pay] Rename the -apple-pay-button-type value "checkout" to "check-out"
https://bugs.webkit.org/show_bug.cgi?id=189366
<rdar://problem/44193218>

Reviewed by Sam Weinig.

Source/WebCore:

The button title is "Check out with Apple Pay", so we should use the verb phrase "check out"
rather than the noun "checkout" for naming this value.

Updated http/tests/ssl/applepay/ApplePayButtonV4.html.

* css/CSSPrimitiveValueMappings.h:
(WebCore::CSSPrimitiveValue::CSSPrimitiveValue):
(WebCore::CSSPrimitiveValue::operator ApplePayButtonType const):
* css/CSSValueKeywords.in:
* css/parser/CSSParserFastPaths.cpp:
(WebCore::CSSParserFastPaths::isValidKeywordPropertyAndValue):
* rendering/RenderThemeCocoa.mm:
(WebCore::toPKPaymentButtonType):
* rendering/style/RenderStyleConstants.h:

Source/WebInspectorUI:

* UserInterface/Models/CSSKeywordCompletions.js:

LayoutTests:

* http/tests/ssl/applepay/ApplePayButtonV4.html:

Modified Paths

Diff

Modified: trunk/LayoutTests/ChangeLog (235753 => 235754)


--- trunk/LayoutTests/ChangeLog	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/LayoutTests/ChangeLog	2018-09-06 20:42:48 UTC (rev 235754)
@@ -1,3 +1,13 @@
+2018-09-06  Andy Estes  <[email protected]>
+
+        [Apple Pay] Rename the -apple-pay-button-type value "checkout" to "check-out"
+        https://bugs.webkit.org/show_bug.cgi?id=189366
+        <rdar://problem/44193218>
+
+        Reviewed by Sam Weinig.
+
+        * http/tests/ssl/applepay/ApplePayButtonV4.html:
+
 2018-09-06  Zalan Bujtas  <[email protected]>
 
         [LFC][BFC] Add support for min(max)-width

Modified: trunk/LayoutTests/http/tests/ssl/applepay/ApplePayButtonV4.html (235753 => 235754)


--- trunk/LayoutTests/http/tests/ssl/applepay/ApplePayButtonV4.html	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/LayoutTests/http/tests/ssl/applepay/ApplePayButtonV4.html	2018-09-06 20:42:48 UTC (rev 235754)
@@ -21,8 +21,8 @@
             -apple-pay-button-style: black;
         }
 
-        .checkout {
-            -apple-pay-button-type: checkout;
+        .check-out {
+            -apple-pay-button-type: check-out;
         }
 
         .book {
@@ -37,7 +37,7 @@
 <body>
     <script>
         for (let style of ["white", "white-outline", "black"]) {
-            for (let type of ["checkout", "book", "subscribe"]) {
+            for (let type of ["check-out", "book", "subscribe"]) {
                 var button = document.createElement("button");
                 button.classList.add("apple-pay-button", style, type);
                 document.body.appendChild(button);

Modified: trunk/Source/WebCore/ChangeLog (235753 => 235754)


--- trunk/Source/WebCore/ChangeLog	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebCore/ChangeLog	2018-09-06 20:42:48 UTC (rev 235754)
@@ -1,3 +1,26 @@
+2018-09-06  Andy Estes  <[email protected]>
+
+        [Apple Pay] Rename the -apple-pay-button-type value "checkout" to "check-out"
+        https://bugs.webkit.org/show_bug.cgi?id=189366
+        <rdar://problem/44193218>
+
+        Reviewed by Sam Weinig.
+
+        The button title is "Check out with Apple Pay", so we should use the verb phrase "check out"
+        rather than the noun "checkout" for naming this value.
+
+        Updated http/tests/ssl/applepay/ApplePayButtonV4.html.
+
+        * css/CSSPrimitiveValueMappings.h:
+        (WebCore::CSSPrimitiveValue::CSSPrimitiveValue):
+        (WebCore::CSSPrimitiveValue::operator ApplePayButtonType const):
+        * css/CSSValueKeywords.in:
+        * css/parser/CSSParserFastPaths.cpp:
+        (WebCore::CSSParserFastPaths::isValidKeywordPropertyAndValue):
+        * rendering/RenderThemeCocoa.mm:
+        (WebCore::toPKPaymentButtonType):
+        * rendering/style/RenderStyleConstants.h:
+
 2018-09-06  Jer Noble  <[email protected]>
 
         Don't pause playback when locking screen if video is being displayed on second screen.

Modified: trunk/Source/WebCore/css/CSSPrimitiveValueMappings.h (235753 => 235754)


--- trunk/Source/WebCore/css/CSSPrimitiveValueMappings.h	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebCore/css/CSSPrimitiveValueMappings.h	2018-09-06 20:42:48 UTC (rev 235754)
@@ -5482,8 +5482,8 @@
         m_value.valueID = CSSValueDonate;
         break;
 #if ENABLE(APPLE_PAY_SESSION_V4)
-    case ApplePayButtonType::Checkout:
-        m_value.valueID = CSSValueCheckout;
+    case ApplePayButtonType::CheckOut:
+        m_value.valueID = CSSValueCheckOut;
         break;
     case ApplePayButtonType::Book:
         m_value.valueID = CSSValueBook;
@@ -5514,8 +5514,8 @@
     case CSSValueDonate:
         return ApplePayButtonType::Donate;
 #if ENABLE(APPLE_PAY_SESSION_V4)
-    case CSSValueCheckout:
-        return ApplePayButtonType::Checkout;
+    case CSSValueCheckOut:
+        return ApplePayButtonType::CheckOut;
     case CSSValueBook:
         return ApplePayButtonType::Book;
     case CSSValueSubscribe:

Modified: trunk/Source/WebCore/css/CSSValueKeywords.in (235753 => 235754)


--- trunk/Source/WebCore/css/CSSValueKeywords.in	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebCore/css/CSSValueKeywords.in	2018-09-06 20:42:48 UTC (rev 235754)
@@ -1337,7 +1337,7 @@
 in-store
 donate
 #if defined(ENABLE_APPLE_PAY_SESSION_V4) && ENABLE_APPLE_PAY_SESSION_V4
-checkout
+check-out
 book
 subscribe
 #endif

Modified: trunk/Source/WebCore/css/parser/CSSParserFastPaths.cpp (235753 => 235754)


--- trunk/Source/WebCore/rendering/RenderThemeCocoa.mm	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebCore/rendering/RenderThemeCocoa.mm	2018-09-06 20:42:48 UTC (rev 235754)
@@ -119,7 +119,7 @@
     case ApplePayButtonType::Donate:
         return PKPaymentButtonTypeDonate;
 #if ENABLE(APPLE_PAY_SESSION_V4)
-    case ApplePayButtonType::Checkout:
+    case ApplePayButtonType::CheckOut:
         return PKPaymentButtonTypeCheckout;
     case ApplePayButtonType::Book:
         return PKPaymentButtonTypeBook;

Modified: trunk/Source/WebCore/rendering/style/RenderStyleConstants.h (235753 => 235754)


--- trunk/Source/WebCore/rendering/style/RenderStyleConstants.h	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebCore/rendering/style/RenderStyleConstants.h	2018-09-06 20:42:48 UTC (rev 235754)
@@ -1129,7 +1129,7 @@
     InStore,
     Donate,
 #if ENABLE(APPLE_PAY_SESSION_V4)
-    Checkout,
+    CheckOut,
     Book,
     Subscribe,
 #endif

Modified: trunk/Source/WebInspectorUI/ChangeLog (235753 => 235754)


--- trunk/Source/WebInspectorUI/ChangeLog	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebInspectorUI/ChangeLog	2018-09-06 20:42:48 UTC (rev 235754)
@@ -1,3 +1,13 @@
+2018-09-06  Andy Estes  <[email protected]>
+
+        [Apple Pay] Rename the -apple-pay-button-type value "checkout" to "check-out"
+        https://bugs.webkit.org/show_bug.cgi?id=189366
+        <rdar://problem/44193218>
+
+        Reviewed by Sam Weinig.
+
+        * UserInterface/Models/CSSKeywordCompletions.js:
+
 2018-08-31  Jamal Nasser  <[email protected]>
 
         Added a CSS rule to DarkMode.css to fix color on sidebar toggle.

Modified: trunk/Source/WebInspectorUI/UserInterface/Models/CSSKeywordCompletions.js (235753 => 235754)


--- trunk/Source/WebInspectorUI/UserInterface/Models/CSSKeywordCompletions.js	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebInspectorUI/UserInterface/Models/CSSKeywordCompletions.js	2018-09-06 20:42:48 UTC (rev 235754)
@@ -1063,6 +1063,6 @@
         "black", "white", "white-outline"
     ],
     "-apple-pay-button-type": [
-        "book", "buy", "checkout", "donate", "in-store", "plain", "set-up", "subscribe"
+        "book", "buy", "check-out", "donate", "in-store", "plain", "set-up", "subscribe"
     ]
 };
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebCore/css/parser/CSSParserFastPaths.cpp	2018-09-06 20:36:41 UTC (rev 235753)
+++ trunk/Source/WebCore/css/parser/CSSParserFastPaths.cpp	2018-09-06 20:42:48 UTC (rev 235754)
@@ -769,11 +769,11 @@
 #if ENABLE(APPLE_PAY)
     case CSSPropertyApplePayButtonStyle: // white | white-outline | black
         return valueID == CSSValueWhite || valueID == CSSValueWhiteOutline || valueID == CSSValueBlack;
-    case CSSPropertyApplePayButtonType: // plain | buy | set-up | in-store | donate | checkout | book | subscribe
+    case CSSPropertyApplePayButtonType: // plain | buy | set-up | in-store | donate | check-out | book | subscribe
         if (valueID == CSSValuePlain || valueID == CSSValueBuy || valueID == CSSValueSetUp || valueID == CSSValueInStore || valueID == CSSValueDonate)
             return true;
 #if ENABLE(APPLE_PAY_SESSION_V4)
-        return valueID == CSSValueCheckout || valueID == CSSValueBook || valueID == CSSValueSubscribe;
+        return valueID == CSSValueCheckOut || valueID == CSSValueBook || valueID == CSSValueSubscribe;
 #else
         return false;
 #endif

Modified: trunk/Source/WebCore/rendering/RenderThemeCocoa.mm (235753 => 235754)

